uhugo.post_install.providers.netlify — uHugo 1.1.10 documentation

# uhugo.post_install.providers.netlify

class uhugo.post_install.providers.netlify.Netlify(api_key: str = None, config_path: str = None, hugo_version: str = None)

  Netlify provider

  Parameters:

    - hugo_version – New Hugo version

    - api_key – Authentication key for providers

    - config_path – Path for configuration file of the provider

  update_config_file(file_name: str)

    Updates `netlify.yaml` file with Hugo’s version

    Parameters:

      file_name – Path of `netlify.yaml`

    Returns: